@@ -53,7 +53,7 @@ class Freebox(IPlugin):
 			if rs['ids'] == idex :
 				log.msg("*************  TROUVé ****************")
 				log.msg("idx  :  %s" % (rs['idx']))
-				log.msg("idx sec :  %s" % (rs['idx_sec']))
+				log.msg("idx sec :  %s" % (int(rs['idx_sec'])))
 				log.msg(" boy  :  %s" % (rs['boy']))
 				if rs['idx_sec'] == "":
 					rs['idx_sec'] == "1"
